/*****************************************************************************
/*
/*            INSTITUTO NACIONAL PARA LA EVALUACIN DE LA EDUCACIN
/*                       DIRECCIN DE PRUEBAS Y MEDICIN
/*                           SUBDIRECCION DE ANLISIS
/*_____________________________________________________________________________
/*
/*            EXAMENES DE LA CALIDAD Y EL LOGRO EDUCATIVOS (Excale)
/*                    TERCER GRADO DE SECUNDARIA (Excale 09)
/*
/*                              **** ESCUELAS ****
/*
/*                     Ciclo escolar evaluado: 2007 - 2008
/*_____________________________________________________________________________
/*
/*
/*            PROGRAMA PARA CONSTRUIR LA BASE DE DATOS DE ESCUELAS
/*                               EN FORMATO SAS
/*_____________________________________________________________________________
/*
/*  El programa convierte al archivo Excale09_2008_Escuelas.txt, el cual est en
/*  formato ASCII, en una base de datos en formato SAS. El programa realiza las
/*  siguientes tareas:
/*   - Declara formatos para algunas variables
/*   - Lee las variables del archivo en formato ASCII
/*   - Declara los valores considerados en el anlisis como perdidos (missing values)
/*
/* INSTRUCCIONES
/*  Para construir la base de datos (tabla de datos) es necesario:
/*      1) Crear una carpeta de trabajo y colocar en ella al archivo Excale09_2008_Escuelas.txt
/*         as como el archivo Excale09_2008_Escuelas.SAS (este archivo) los cules se pueden
/*         descargar del sitio web del INEE (www.inee.edu.mx).
/*      2) Modificar la primera y segunda lnea de los comandos de este archivo
/*         (libname y filename) para actualizar el nombre de la librera y el archivo
/*         de trabajo.
/*      3) Ejecutar el programa del archivo.
/*
/*  Al finalizar, se deber contar con la base de datos (tabla de datos) Excale09_2008_Escuelas.sas7bdat
/*
/*  Posteriormente, cuando se desee utilizar nuevamente la base Excale09_2008_Escuelas.sas7bdat,
/*  se deber ejecutar primero el procedimiento FORMAT ("proc FORMAT") de este programa para que
/*  SAS cargue los formatos necesarios para abrir la base.
/*
/* CONTACTO:
/*
/*      Para mayor informacin o aclaracin de dudas favor de contactar a la
/*      Subdireccin de Anlisis del Instituto
/*      Correo electrnico: excale.analisis@inee.edu.mx
/*      Tel 5482 0900 Ext. 1082
/*      Domicilio: Jos Ma. Velasco No. 101. 3er piso. Col. San Jos Insurgentes
/*                 Del. Benito Jurez. Mxico. D.F.
/*
/* FECHA DE LIBERACIN: 16 DE MARZO DEL 2010
/*
/*  ****************************************************************************/


LIBNAME  INEE  "C:***\";
FILENAME esc   "C:\***\Excale09_2008_Escuelas.TXT";

PROC FORMAT;
     VALUE id_entF     1         = "Aguascalientes"
                       2         = "Baja California"
                       3         = "Baja California Sur"
                       4         = "Campeche"
                       5         = "Coahuila"
                       6         = "Colima"
                       7         = "Chiapas"
                       8         = "Chihuahua"
                       9         = "Distrito Federal"
                       10        = "Durango"
                       11        = "Guanajuato"
                       12        = "Guerrero"
                       13        = "Hidalgo"
                       14        = "Jalisco"
                       15        = "Mxico"
                       16        = "Michoacn"
                       17        = "Morelos"
                       18        = "Nayarit"
                       19        = "Nuevo Len"
                       20        = "Oaxaca"
                       21        = "Puebla"
                       22        = "Quertaro"
                       23        = "Quintana Roo"
                       24        = "San Luis Potos"
                       25        = "Sinaloa"
                       26        = "Sonora"
                       27        = "Tabasco"
                       28        = "Tamaulipas"
                       29        = "Tlaxcala"
                       30        = "Veracruz"
                       31        = "Yucatn"
                       32        = "Zacatecas";
     VALUE id_turnF    1         = "Matutino"
                       2         = "Vespertino"
                       3         = "Nocturno"
                       4         = "Discontinuo"
                       5         = "Mixto";
     VALUE id_modF     6         = "General"
                       7         = "Tcnica"
                       8         = "Telesecundaria"
                       9         = "Privada";
     VALUE $modF       "GRAL"    = "General"
                       "TEC"     = "Tcnica"
                       "TV"      = "Telesecundaria"
                       "PRIV"    = "Privada";
     VALUE $mageb05F   "R"       = "Escuela rural"
                       "UA"      = "Escuela urbana de alta marginacin"
                       "UB"      = "Escuela urbana de baja marginacin"
                       "NA"      = "No aplica";
RUN;



DATA INEE.Excale09_2008_Escuelas;
   LENGTH
       proyecto           $6
       anio               4
       escuela            4
       id_ent             3
       nom_ent            $19
       id_turno           3
       turno_esc          $10
       id_mod             3
       mod                $4
       mageb05            $2
       entest             $6
       alu_esc            3
       alu_Shi            3
       esc_Uh             4

   ;

INFILE esc MISSOVER LINESIZE = 68;
   INPUT
        proyecto         1 - 6
        anio             7 - 10
        escuela         11 - 14
        id_ent          15 - 16
        nom_ent         17 - 35
        id_turno        36 - 36
        turno_esc       37 - 46
        id_mod          47 - 47
        mod             48 - 51
        mageb05         52 - 53
        entest          54 - 59
        alu_esc         60 - 62
        alu_shi         63 - 64
        esc_uh          65 - 68
   ;

   LABEL
      proyecto    = "Proyecto al que pertenece el estudio"
      anio         = "Ao del levantamiento de datos"
      escuela     = "Identificador de la escuela"
      id_ent      = "Entidad federativa (identificador numrico)"
      nom_ent     = "Entidad federativa"
      id_turno    = "Turno de la escuela (numrico)"
      turno_esc   = "Turno de la escuela"
      id_mod      = "Estrato escolar o Modalidad educativa (identificador numrico)"
      mod         = "Estrato escolar o Modalidad educativa"
      mageb05     = "ndice de marginacin urbana 2005"
      entest      = "Estratos del diseo muestral con el que se estiman los parmetros y errores estndar (Entidad federativa-Modalidad-Densidad de poblacin)"
      alu_esc     = "Cantidad de alumnos de 3o de secundaria en la escuela"
      alu_shi     = "Cantidad de alumnos evaluados en la escuela"
      esc_uh      = "Cantidad de escuelas en el estrato muestral ENTEST"

   ;

   FORMAT
        id_ent            id_entF.
        id_turno          id_turnF.
        id_mod            id_modF.
        mod               $modF.
        mageb05           $mageb05F.
   ;



RUN;



